==> chimera-ble-0.1.1-sources.jar: com/chimeraiot/android/ble/BleScannerPreLollipop.java <==
/*
 * Copyright (c) 2015 Chimera IoT
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.chimeraiot.android.ble;

import android.bluetooth.BluetoothAdapter;

import java.util.Collection;
import java.util.Collections;

/** BLE devices list scanner. */
@SuppressWarnings("deprecation")
/*package*/ class BleScannerPreLollipop implements Runnable, BleScanner {
    /** Logging tag. */
    private static final String TAG = BleScannerPreLollipop.class.getSimpleName();

    /** Default scan period. */
    private static final long DEFAULT_SCAN_PERIOD = 3000L;
    /** Value of period used to scan for list of ble devices once. */
    public static final long PERIOD_SCAN_ONCE = -1;

    /** Bluetooth adapter. */
    private final BluetoothAdapter bluetoothAdapter;

    /** Scan period. */
    private long scanPeriod = DEFAULT_SCAN_PERIOD;
    /** Scan thread. */
    private Thread scanThread;
    /** Indicates whether scanner is running. */
    private volatile boolean isScanning = false;
    /** Scan process listener. */
    private BleDevicesScannerListener listener;

    public BleScannerPreLollipop(BluetoothAdapter adapter, BleDevicesScannerListener listener) {
        if (adapter == null) {
            throw new IllegalArgumentException("Adapter should not be null");
        }

        this.listener = listener;
        bluetoothAdapter = adapter;
    }

    @SuppressWarnings("UnusedDeclaration")
    public synchronized void setScanPeriod(long scanPeriod) {
        this.scanPeriod = scanPeriod < 0 ? PERIOD_SCAN_ONCE : scanPeriod;
    }

    public boolean isScanning() {
        return scanThread != null && scanThread.isAlive();
    }

    public synchronized void start() {
        start(Collections.<String>emptyList());
    }

    public synchronized void start(Collection<String> filter) {
        if (isScanning()) {
            return;
        }

        if (scanThread != null) {
            scanThread.interrupt();
        }
        scanThread = new Thread(this);
        scanThread.setName(TAG);
        scanThread.start();
    }

    public synchronized void stop() {
        isScanning = false;
        if (scanThread != null) {
            scanThread.interrupt();
            scanThread = null;
        }
        bluetoothAdapter.stopLeScan(listener);
    }

    @Override
    public void run() {
        try {
            isScanning = true;
            listener.onScanStarted();

            do {
                synchronized (this) {
                    bluetoothAdapter.startLeScan(listener);
                }

                if (scanPeriod > 0) {
                    Thread.sleep(scanPeriod);
                } else {
                    Thread.sleep(DEFAULT_SCAN_PERIOD);
                }

                synchronized (this) {
                    bluetoothAdapter.startLeScan(listener);
                }

                if (scanPeriod > 0) {
                    listener.onScanRepeat();
                }
            } while (isScanning && scanPeriod > 0);
            //CHECKSTYLE:OFF
        } catch (InterruptedException ignore) {
        } finally {
            //CHECKSTYLE:ON
            synchronized (this) {
                bluetoothAdapter.startLeScan(listener);
            }
        }

        listener.onScanStopped();
    }

}

==> chimera-ble-0.1.5-sources.jar: com/chimeraiot/android/ble/BleScannerPreLollipop.java <==
/*
 * Copyright (c) 2015 Chimera IoT
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.chimeraiot.android.ble;

import android.bluetooth.BluetoothAdapter;

import java.util.Collection;
import java.util.Collections;

/** BLE devices list scanner. */
@SuppressWarnings("deprecation")
/*package*/ class BleScannerPreLollipop implements Runnable, BleScanner {
    /** Logging tag. */
    private static final String TAG = BleScannerPreLollipop.class.getSimpleName();

    /** Bluetooth adapter. */
    private final BluetoothAdapter bluetoothAdapter;

    /** Scan period. */
    private long scanPeriod = DEFAULT_SCAN_PERIOD;
    /** Scan thread. */
    private Thread scanThread;
    /** Indicates whether scanner is running. */
    private volatile boolean isScanning = false;
    /** Scan process listener. */
    private BleDevicesScannerListener listener;

    public BleScannerPreLollipop(BluetoothAdapter adapter, BleDevicesScannerListener listener) {
        if (adapter == null) {
            throw new IllegalArgumentException("Adapter should not be null");
        }

        this.listener = listener;
        bluetoothAdapter = adapter;
    }

    @Override
    @SuppressWarnings("UnusedDeclaration")
    public synchronized void setScanPeriod(long scanPeriod) {
        this.scanPeriod = scanPeriod < 0 ? PERIOD_SCAN_ONCE : scanPeriod;
    }

    @Override
    public void setScanMode(final int scanMode) {
        // no-op
    }

    @Override
    public boolean isScanning() {
        return scanThread != null && scanThread.isAlive();
    }

    @Override
    public synchronized void start() {
        start(Collections.<String>emptyList());
    }

    @Override
    public synchronized void start(Collection<String> filter) {
        if (isScanning()) {
            return;
        }

        if (scanThread != null) {
            scanThread.interrupt();
        }
        scanThread = new Thread(this);
        scanThread.setName(TAG);
        scanThread.start();
    }

    @Override
    public synchronized void stop() {
        isScanning = false;
        if (scanThread != null) {
            scanThread.interrupt();
            scanThread = null;
        }
        bluetoothAdapter.stopLeScan(listener);
    }

    @Override
    public void run() {
        try {
            isScanning = true;
            listener.onScanStarted();

            do {
                synchronized (this) {
                    bluetoothAdapter.startLeScan(listener);
                }

                if (scanPeriod > 0) {
                    Thread.sleep(scanPeriod);
                } else {
                    Thread.sleep(DEFAULT_SCAN_PERIOD);
                }

                synchronized (this) {
                    bluetoothAdapter.startLeScan(listener);
                }

                if (scanPeriod > 0) {
                    listener.onScanRepeat();
                }
            } while (isScanning && scanPeriod > 0);
            //CHECKSTYLE:OFF
        } catch (InterruptedException ignore) {
        } finally {
            //CHECKSTYLE:ON
            synchronized (this) {
                bluetoothAdapter.startLeScan(listener);
            }
        }

        listener.onScanStopped();
    }

}
